تست پلاگین انتخاب تاریخ

نمونه روشهای استفاده از پلاگین datepicker با تاریخ هجری شمسی
توسط: مهدی هاشمی نژاد
ارایه نظرات و گزارش باگ: hasheminezhad at gmail dot com
بروز شده به نسخه jquery-ui-1.10.3 توسط گروه Caspico

حالت پیشفرض
تاریخ:

نمایش شماره هفته
تاریخ:

پرکردن فیلد اضافی
تاریخ:

نمایش دکمه ها
تاریخ:

تغییر قالب نمایش تاریخ و تغییر سایز خودکار فیلد
تاریخ:

استفاده از dropdown
تاریخ:

انتخاب با کلیک بر روی عکس
تاریخ:

نمایش inline

نمایش چند ماه
تاریخ:

غیرفعال کردن روزها
تاریخ:

تاریخ پیشفرض
تاریخ:

تنظیم حداقل و حداکثر
تاریخ:

تنظیم حداقل بصورت پویا
از تاریخ: تا تاریخ:

استفاده همزمان از تقویم میلادی
تاریخ:

استفاده همزمان از تقویم هجری قمری
تاریخ: